import { Output, TemplateRef, EventEmitter, Component, ViewContainerRef, ViewChild, Input, ChangeDetectionStrategy, HostBinding } from '@angular/core';
import { XButton } from "./XButton";
import { ensureEnum, brushToString, stringToBrush, ensureBool, toSpinal, initializePropertiesFromCss, NamePatcher } from "igniteui-angular-core";
import { FontInfo } from "igniteui-angular-core";
import { AngularRenderer, PortalManager } from "igniteui-angular-core";
import { delegateCombine } from "igniteui-angular-core";
import { CornerRadius } from "igniteui-angular-core";
import { ButtonDisplayStyle_$type } from './ButtonDisplayStyle';
import { IgxButtonClickEventArgs } from './igx-button-click-event-args';
import { TypeRegistrar } from "igniteui-angular-core";
import { ControlDisplayDensity_$type } from "igniteui-angular-core";
import { ElevationMode_$type } from "igniteui-angular-core";
import { BaseControlTheme_$type } from "igniteui-angular-core";
import { HorizontalAlignment_$type } from "igniteui-angular-core";
import { VerticalAlignment_$type } from "igniteui-angular-core";
import { IgxFocusEventArgs } from "igniteui-angular-core";
import * as i0 from "@angular/core";
export let IgxXButtonComponent = /*@__PURE__*/ (() => {
    class IgxXButtonComponent {
        constructor(renderer, _elRef, ngZone, injector, componentFactoryResolver) {
            this.renderer = renderer;
            this._elRef = _elRef;
            this.ngZone = ngZone;
            this.injector = injector;
            this.componentFactoryResolver = componentFactoryResolver;
            this._wrapper = null;
            this._portalManager = null;
            this._root = null;
            this.__p = null;
            this._hasUserValues = new Set();
            this._stylingContainer = null;
            this._stylingParent = null;
            this._inStyling = false;
            this._clicked = null;
            this._gotFocus = null;
            this._lostFocus = null;
            this._zoneRunner = null;
            if (this._styling) {
                NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
            }
            this._implementation = this.createImplementation();
            this._implementation.externalObject = this;
            if (renderer) {
                this.container = renderer.createElement("div");
                renderer.appendChild(_elRef.element.nativeElement, this.container);
                renderer.setStyle(this.container, "display", "inline-block");
            }
            var root;
            root = this.container;
            if (this.container != null) {
                root = this.container;
            }
            if (root && root.nativeElement) {
                root = root.nativeElement;
            }
            this._root = root;
            var button = this.i;
            this._button = button;
            if (renderer) {
                this._portalManager = new PortalManager("buttonContent", componentFactoryResolver);
                var ren = new AngularRenderer(root, this.renderer, window.document, this.ngZone, true, {}, this._portalManager);
                this._wrapper = ren;
                button.provideContainer(ren);
            }
        }
        // supports angular themes or custom properties set in CSS
        updateStyle() {
            this._styling(this._root, this);
        }
        ngOnDestroy() {
            this._button.destroy();
            this._wrapper.destroy();
        }
        ngAfterViewInit() {
            this._portalManager.dynamicContent = this._dynamicContent;
            this._portalManager.onChildContentChanged(this._childTemplateRef);
            this._styling(this._root, this);
            this.updateStyle();
        }
        createImplementation() {
            return new XButton();
        }
        /**
         * @hidden
         */
        get i() {
            return this._implementation;
        } /**
                                     * @hidden
                                     */
        static _createFromInternal(internal) {
            if (!internal) {
                return null;
            }
            if (!internal.$type) {
                return null;
            }
            let name = internal.$type.name;
            let externalName = "Igx" + name + "Component";
            if (!TypeRegistrar.isRegistered(externalName)) {
                return null;
            }
            return TypeRegistrar.create(externalName);
        }
        /**
     * Gets or sets the min width to use for the button.
    */
        get minWidth() {
            return this.i.bu;
        }
        set minWidth(v) {
            this.i.bu = +v;
        }
        /**
         * Gets or sets the min height to use for the button.
        */
        get minHeight() {
            return this.i.bt;
        }
        set minHeight(v) {
            this.i.bt = +v;
        }
        /**
         * Gets or sets the display style to use for the button.
        */
        get displayType() {
            return this.i.e;
        }
        set displayType(v) {
            this.i.e = ensureEnum(ButtonDisplayStyle_$type, v);
        }
        /**
         * Gets or sets the display density to use for the button.
        */
        get density() {
            return this.i.r;
        }
        set density(v) {
            this.i.r = ensureEnum(ControlDisplayDensity_$type, v);
        }
        /**
         * Gets or sets the base built in theme to use for the button.
        */
        get baseTheme() {
            return this.i.n;
        }
        set baseTheme(v) {
            this.i.n = ensureEnum(BaseControlTheme_$type, v);
        }
        /**
         * Gets the actual display density to use for the label.
        */
        get actualDensity() {
            return this.i.q;
        }
        set actualDensity(v) {
            this.i.q = ensureEnum(ControlDisplayDensity_$type, v);
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualBorderColor() {
            return brushToString(this.i.ng);
        }
        set actualBorderColor(v) {
            this.i.ng = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualUmbraShadowColor() {
            return brushToString(this.i.nr);
        }
        set actualUmbraShadowColor(v) {
            this.i.nr = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualPenumbraShadowColor() {
            return brushToString(this.i.no);
        }
        set actualPenumbraShadowColor(v) {
            this.i.no = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualAmbientShadowColor() {
            return brushToString(this.i.ne);
        }
        set actualAmbientShadowColor(v) {
            this.i.ne = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualRestingElevation() {
            return this.i.ct;
        }
        set actualRestingElevation(v) {
            this.i.ct = +v;
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualFocusElevation() {
            return this.i.cr;
        }
        set actualFocusElevation(v) {
            this.i.cr = +v;
        }
        /**
         * Gets or sets the color to use for the check mark when the checkbox is checked.
        */
        get actualHoverElevation() {
            return this.i.cs;
        }
        set actualHoverElevation(v) {
            this.i.cs = +v;
        }
        /**
         * Gets or sets the color to use for the ripple when the button is pressed.
        */
        get actualRippleColor() {
            return brushToString(this.i.np);
        }
        set actualRippleColor(v) {
            this.i.np = stringToBrush(v);
        }
        get actualCornerRadiusBottomRight() {
            return this.i.kr ? this.i.kr.b : NaN;
        }
        set actualCornerRadiusBottomRight(v) {
            this.ensureActualCornerRadius();
            this.i.kr.b = +v;
            this.i.kr = this.i.kr;
        }
        get actualCornerRadiusBottomLeft() {
            return this.i.kr ? this.i.kr.a : NaN;
        }
        set actualCornerRadiusBottomLeft(v) {
            this.ensureActualCornerRadius();
            this.i.kr.a = +v;
            this.i.kr = this.i.kr;
        }
        get actualCornerRadiusTopLeft() {
            return this.i.kr ? this.i.kr.c : NaN;
        }
        set actualCornerRadiusTopLeft(v) {
            this.ensureActualCornerRadius();
            this.i.kr.c = +v;
            this.i.kr = this.i.kr;
        }
        get actualCornerRadiusTopRight() {
            return this.i.kr ? this.i.kr.d : NaN;
        }
        set actualCornerRadiusTopRight(v) {
            this.ensureActualCornerRadius();
            this.i.kr.d = +v;
            this.i.kr = this.i.kr;
        }
        ensureActualCornerRadius() {
            if (this.i.kr) {
                return;
            }
            this.i.kr = new CornerRadius(2);
        }
        /**
         * Gets the color to use for the actual background.
        */
        get actualBackgroundColor() {
            return brushToString(this.i.nf);
        }
        set actualBackgroundColor(v) {
            this.i.nf = stringToBrush(v);
        }
        /**
         * Gets the actual color to use for the disabled background of the button.
        */
        get actualDisabledBackgroundColor() {
            return brushToString(this.i.nh);
        }
        set actualDisabledBackgroundColor(v) {
            this.i.nh = stringToBrush(v);
        }
        /**
         * Gets the actual color to use for the disabled border of the button.
        */
        get actualDisabledBorderColor() {
            return brushToString(this.i.ni);
        }
        set actualDisabledBorderColor(v) {
            this.i.ni = stringToBrush(v);
        }
        /**
         * Gets the actual color to use for the disabled text of the button.
        */
        get actualDisabledTextColor() {
            return brushToString(this.i.nj);
        }
        set actualDisabledTextColor(v) {
            this.i.nj = stringToBrush(v);
        }
        /**
         * Gets the actual disabled elevation to use for the button.
        */
        get actualDisabledElevation() {
            return this.i.cq;
        }
        set actualDisabledElevation(v) {
            this.i.cq = +v;
        }
        /**
         * Gets the actual disabled elevation to use for the button.
        */
        get actualElevationMode() {
            return this.i.u;
        }
        set actualElevationMode(v) {
            this.i.u = ensureEnum(ElevationMode_$type, v);
        }
        /**
         * Gets the color to use for the actual background.
        */
        get actualTextColor() {
            return brushToString(this.i.nq);
        }
        set actualTextColor(v) {
            this.i.nq = stringToBrush(v);
        }
        /**
         * Gets the color to use for the actual background.
        */
        get actualHoverTextColor() {
            return brushToString(this.i.nn);
        }
        set actualHoverTextColor(v) {
            this.i.nn = stringToBrush(v);
        }
        /**
         * Gets the color to use for the actual background.
        */
        get actualFocusBackgroundColor() {
            return brushToString(this.i.nk);
        }
        set actualFocusBackgroundColor(v) {
            this.i.nk = stringToBrush(v);
        }
        /**
         * Gets the actual color to use for the focused text.
        */
        get actualFocusTextColor() {
            return brushToString(this.i.nl);
        }
        set actualFocusTextColor(v) {
            this.i.nl = stringToBrush(v);
        }
        /**
         * Gets the hover color to use for the actual background.
        */
        get actualHoverBackgroundColor() {
            return brushToString(this.i.nm);
        }
        set actualHoverBackgroundColor(v) {
            this.i.nm = stringToBrush(v);
        }
        /**
         * Gets or sets the Width to use for the check mark when the checkbox is checked.
        */
        get actualBorderWidth() {
            return this.i.bf;
        }
        set actualBorderWidth(v) {
            this.i.bf = +v;
        }
        /**
         * Gets or sets the color to use for the background of the button when the  type is raised.
        */
        get raisedBackgroundColor() {
            return brushToString(this.i.qv);
        }
        set raisedBackgroundColor(v) {
            this.i.qv = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is raised.
        */
        get raisedDisabledBackgroundColor() {
            return brushToString(this.i.qx);
        }
        set raisedDisabledBackgroundColor(v) {
            this.i.qx = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is raised.
        */
        get raisedDisabledBorderColor() {
            return brushToString(this.i.qy);
        }
        set raisedDisabledBorderColor(v) {
            this.i.qy = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is raised.
        */
        get raisedDisabledTextColor() {
            return brushToString(this.i.qz);
        }
        set raisedDisabledTextColor(v) {
            this.i.qz = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is raised.
        */
        get raisedDisabledElevation() {
            return this.i.dy;
        }
        set raisedDisabledElevation(v) {
            this.i.dy = +v;
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the  type is raised.
        */
        get raisedHoverBackgroundColor() {
            return brushToString(this.i.q2);
        }
        set raisedHoverBackgroundColor(v) {
            this.i.q2 = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button when the type is raised.
        */
        get raisedBorderColor() {
            return brushToString(this.i.qw);
        }
        set raisedBorderColor(v) {
            this.i.qw = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button when the type is raised.
        */
        get raisedRestingElevation() {
            return this.i.d1;
        }
        set raisedRestingElevation(v) {
            this.i.d1 = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button when the type is raised.
        */
        get raisedHoverElevation() {
            return this.i.d0;
        }
        set raisedHoverElevation(v) {
            this.i.d0 = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button when the type is raised.
        */
        get raisedFocusElevation() {
            return this.i.dz;
        }
        set raisedFocusElevation(v) {
            this.i.dz = +v;
        }
        /**
         * Gets or sets the width to use for the button border when the type is raised.
        */
        get raisedBorderWidth() {
            return this.i.bw;
        }
        set raisedBorderWidth(v) {
            this.i.bw = +v;
        }
        get raisedCornerRadiusBottomRight() {
            return this.i.k3 ? this.i.k3.b : NaN;
        }
        set raisedCornerRadiusBottomRight(v) {
            this.ensureRaisedCornerRadius();
            this.i.k3.b = +v;
            this.i.k3 = this.i.k3;
        }
        get raisedCornerRadiusBottomLeft() {
            return this.i.k3 ? this.i.k3.a : NaN;
        }
        set raisedCornerRadiusBottomLeft(v) {
            this.ensureRaisedCornerRadius();
            this.i.k3.a = +v;
            this.i.k3 = this.i.k3;
        }
        get raisedCornerRadiusTopLeft() {
            return this.i.k3 ? this.i.k3.c : NaN;
        }
        set raisedCornerRadiusTopLeft(v) {
            this.ensureRaisedCornerRadius();
            this.i.k3.c = +v;
            this.i.k3 = this.i.k3;
        }
        get raisedCornerRadiusTopRight() {
            return this.i.k3 ? this.i.k3.d : NaN;
        }
        set raisedCornerRadiusTopRight(v) {
            this.ensureRaisedCornerRadius();
            this.i.k3.d = +v;
            this.i.k3 = this.i.k3;
        }
        ensureRaisedCornerRadius() {
            if (this.i.k3) {
                return;
            }
            this.i.k3 = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background when the button is pressed and the type is floating action button.
        */
        get raisedRippleColor() {
            return brushToString(this.i.q4);
        }
        set raisedRippleColor(v) {
            this.i.q4 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the background of the button when the type is flat.
        */
        get flatBackgroundColor() {
            return brushToString(this.i.pu);
        }
        set flatBackgroundColor(v) {
            this.i.pu = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is flat.
        */
        get flatDisabledBackgroundColor() {
            return brushToString(this.i.pw);
        }
        set flatDisabledBackgroundColor(v) {
            this.i.pw = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is flat.
        */
        get flatDisabledBorderColor() {
            return brushToString(this.i.px);
        }
        set flatDisabledBorderColor(v) {
            this.i.px = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is flat.
        */
        get flatDisabledTextColor() {
            return brushToString(this.i.py);
        }
        set flatDisabledTextColor(v) {
            this.i.py = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is flat.
        */
        get flatDisabledElevation() {
            return this.i.dj;
        }
        set flatDisabledElevation(v) {
            this.i.dj = +v;
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the type is flat.
        */
        get flatHoverBackgroundColor() {
            return brushToString(this.i.p1);
        }
        set flatHoverBackgroundColor(v) {
            this.i.p1 = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button when the type is flat.
        */
        get flatBorderColor() {
            return brushToString(this.i.pv);
        }
        set flatBorderColor(v) {
            this.i.pv = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button when the type is flat.
        */
        get flatRestingElevation() {
            return this.i.dm;
        }
        set flatRestingElevation(v) {
            this.i.dm = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button when the type is flat.
        */
        get flatHoverElevation() {
            return this.i.dl;
        }
        set flatHoverElevation(v) {
            this.i.dl = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button when the type is flat.
        */
        get flatFocusElevation() {
            return this.i.dk;
        }
        set flatFocusElevation(v) {
            this.i.dk = +v;
        }
        /**
         * Gets or sets the color to use for the background when the button is pressed and the type is floating action button.
        */
        get flatRippleColor() {
            return brushToString(this.i.p3);
        }
        set flatRippleColor(v) {
            this.i.p3 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when type is flat.
        */
        get flatTextColor() {
            return brushToString(this.i.p4);
        }
        set flatTextColor(v) {
            this.i.p4 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button when type is flat.
        */
        get flatHoverTextColor() {
            return brushToString(this.i.p2);
        }
        set flatHoverTextColor(v) {
            this.i.p2 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused and flat.
        */
        get flatFocusBackgroundColor() {
            return brushToString(this.i.pz);
        }
        set flatFocusBackgroundColor(v) {
            this.i.pz = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text the button when it is focused and flat.
        */
        get flatFocusTextColor() {
            return brushToString(this.i.p0);
        }
        set flatFocusTextColor(v) {
            this.i.p0 = stringToBrush(v);
        }
        /**
         * Gets or sets the width to use for the button border when the type is flat.
        */
        get flatBorderWidth() {
            return this.i.br;
        }
        set flatBorderWidth(v) {
            this.i.br = +v;
        }
        get flatCornerRadiusBottomRight() {
            return this.i.k0 ? this.i.k0.b : NaN;
        }
        set flatCornerRadiusBottomRight(v) {
            this.ensureFlatCornerRadius();
            this.i.k0.b = +v;
            this.i.k0 = this.i.k0;
        }
        get flatCornerRadiusBottomLeft() {
            return this.i.k0 ? this.i.k0.a : NaN;
        }
        set flatCornerRadiusBottomLeft(v) {
            this.ensureFlatCornerRadius();
            this.i.k0.a = +v;
            this.i.k0 = this.i.k0;
        }
        get flatCornerRadiusTopLeft() {
            return this.i.k0 ? this.i.k0.c : NaN;
        }
        set flatCornerRadiusTopLeft(v) {
            this.ensureFlatCornerRadius();
            this.i.k0.c = +v;
            this.i.k0 = this.i.k0;
        }
        get flatCornerRadiusTopRight() {
            return this.i.k0 ? this.i.k0.d : NaN;
        }
        set flatCornerRadiusTopRight(v) {
            this.ensureFlatCornerRadius();
            this.i.k0.d = +v;
            this.i.k0 = this.i.k0;
        }
        ensureFlatCornerRadius() {
            if (this.i.k0) {
                return;
            }
            this.i.k0 = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background when the button regardless of type.
        */
        get backgroundColor() {
            return brushToString(this.i.ns);
        }
        set backgroundColor(v) {
            this.i.ns = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is disabled.
        */
        get disabledBackgroundColor() {
            return brushToString(this.i.pg);
        }
        set disabledBackgroundColor(v) {
            this.i.pg = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is raised.
        */
        get disabledBorderColor() {
            return brushToString(this.i.ph);
        }
        set disabledBorderColor(v) {
            this.i.ph = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is raised.
        */
        get disabledTextColor() {
            return brushToString(this.i.pi);
        }
        set disabledTextColor(v) {
            this.i.pi = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is raised.
        */
        get disabledElevation() {
            return this.i.de;
        }
        set disabledElevation(v) {
            this.i.de = +v;
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is raised.
        */
        get elevationMode() {
            return this.i.w;
        }
        set elevationMode(v) {
            this.i.w = ensureEnum(ElevationMode_$type, v);
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the  type is hovered.
        */
        get hoverBackgroundColor() {
            return brushToString(this.i.p7);
        }
        set hoverBackgroundColor(v) {
            this.i.p7 = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button regardless of type.
        */
        get borderColor() {
            return brushToString(this.i.nt);
        }
        set borderColor(v) {
            this.i.nt = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button regardless of type.
        */
        get restingElevation() {
            return this.i.d2;
        }
        set restingElevation(v) {
            this.i.d2 = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button regardless of type.
        */
        get hoverElevation() {
            return this.i.dp;
        }
        set hoverElevation(v) {
            this.i.dp = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button regardless of type.
        */
        get focusElevation() {
            return this.i.dn;
        }
        set focusElevation(v) {
            this.i.dn = +v;
        }
        /**
         * Gets or sets the use for the button.
        */
        get textStyle() {
            if (this.i.aa == null) {
                return null;
            }
            return this.i.aa.fontString;
        }
        set textStyle(v) {
            let fi = new FontInfo();
            fi.fontString = v;
            this.i.aa = fi;
        }
        /**
         * Gets or sets the color to use for the text of the button regardless of type.
        */
        get textColor() {
            return brushToString(this.i.q7);
        }
        set textColor(v) {
            this.i.q7 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button regardless of type.
        */
        get hoverTextColor() {
            return brushToString(this.i.p8);
        }
        set hoverTextColor(v) {
            this.i.p8 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the background of the button regardless of type.
        */
        get rippleColor() {
            return brushToString(this.i.q6);
        }
        set rippleColor(v) {
            this.i.q6 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when type is raised.
        */
        get raisedTextColor() {
            return brushToString(this.i.q5);
        }
        set raisedTextColor(v) {
            this.i.q5 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button when type is raised.
        */
        get raisedHoverTextColor() {
            return brushToString(this.i.q3);
        }
        set raisedHoverTextColor(v) {
            this.i.q3 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused and raised.
        */
        get raisedFocusBackgroundColor() {
            return brushToString(this.i.q0);
        }
        set raisedFocusBackgroundColor(v) {
            this.i.q0 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text the button when it is focused and raised.
        */
        get raisedFocusTextColor() {
            return brushToString(this.i.q1);
        }
        set raisedFocusTextColor(v) {
            this.i.q1 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused.
        */
        get focusBackgroundColor() {
            return brushToString(this.i.p5);
        }
        set focusBackgroundColor(v) {
            this.i.p5 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when it is focused.
        */
        get focusTextColor() {
            return brushToString(this.i.p6);
        }
        set focusTextColor(v) {
            this.i.p6 = stringToBrush(v);
        }
        /**
         * Gets or sets the width to use for the button border regardless of type.
        */
        get borderWidth() {
            return this.i.bg;
        }
        set borderWidth(v) {
            this.i.bg = +v;
        }
        get cornerRadiusBottomRight() {
            return this.i.kt ? this.i.kt.b : NaN;
        }
        set cornerRadiusBottomRight(v) {
            this.ensureCornerRadius();
            this.i.kt.b = +v;
            this.i.kt = this.i.kt;
        }
        get cornerRadiusBottomLeft() {
            return this.i.kt ? this.i.kt.a : NaN;
        }
        set cornerRadiusBottomLeft(v) {
            this.ensureCornerRadius();
            this.i.kt.a = +v;
            this.i.kt = this.i.kt;
        }
        get cornerRadiusTopLeft() {
            return this.i.kt ? this.i.kt.c : NaN;
        }
        set cornerRadiusTopLeft(v) {
            this.ensureCornerRadius();
            this.i.kt.c = +v;
            this.i.kt = this.i.kt;
        }
        get cornerRadiusTopRight() {
            return this.i.kt ? this.i.kt.d : NaN;
        }
        set cornerRadiusTopRight(v) {
            this.ensureCornerRadius();
            this.i.kt.d = +v;
            this.i.kt = this.i.kt;
        }
        ensureCornerRadius() {
            if (this.i.kt) {
                return;
            }
            this.i.kt = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background of the button when the  type is outlined.
        */
        get outlinedBackgroundColor() {
            return brushToString(this.i.qk);
        }
        set outlinedBackgroundColor(v) {
            this.i.qk = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is outlined.
        */
        get outlinedDisabledBackgroundColor() {
            return brushToString(this.i.qm);
        }
        set outlinedDisabledBackgroundColor(v) {
            this.i.qm = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is outlined.
        */
        get outlinedDisabledBorderColor() {
            return brushToString(this.i.qn);
        }
        set outlinedDisabledBorderColor(v) {
            this.i.qn = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is outlined.
        */
        get outlinedDisabledTextColor() {
            return brushToString(this.i.qo);
        }
        set outlinedDisabledTextColor(v) {
            this.i.qo = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is outlined.
        */
        get outlinedDisabledElevation() {
            return this.i.du;
        }
        set outlinedDisabledElevation(v) {
            this.i.du = +v;
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the  type is hoveredOutlined.
        */
        get outlinedHoverBackgroundColor() {
            return brushToString(this.i.qr);
        }
        set outlinedHoverBackgroundColor(v) {
            this.i.qr = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button when the type is outlined.
        */
        get outlinedBorderColor() {
            return brushToString(this.i.ql);
        }
        set outlinedBorderColor(v) {
            this.i.ql = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button when the type is outlined.
        */
        get outlinedRestingElevation() {
            return this.i.dx;
        }
        set outlinedRestingElevation(v) {
            this.i.dx = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button when the type is outlined.
        */
        get outlinedHoverElevation() {
            return this.i.dw;
        }
        set outlinedHoverElevation(v) {
            this.i.dw = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button when the type is outlined.
        */
        get outlinedFocusElevation() {
            return this.i.dv;
        }
        set outlinedFocusElevation(v) {
            this.i.dv = +v;
        }
        /**
         * Gets or sets the width to use for the button border when the type is outlined.
        */
        get outlinedBorderWidth() {
            return this.i.bv;
        }
        set outlinedBorderWidth(v) {
            this.i.bv = +v;
        }
        get outlinedCornerRadiusBottomRight() {
            return this.i.k2 ? this.i.k2.b : NaN;
        }
        set outlinedCornerRadiusBottomRight(v) {
            this.ensureOutlinedCornerRadius();
            this.i.k2.b = +v;
            this.i.k2 = this.i.k2;
        }
        get outlinedCornerRadiusBottomLeft() {
            return this.i.k2 ? this.i.k2.a : NaN;
        }
        set outlinedCornerRadiusBottomLeft(v) {
            this.ensureOutlinedCornerRadius();
            this.i.k2.a = +v;
            this.i.k2 = this.i.k2;
        }
        get outlinedCornerRadiusTopLeft() {
            return this.i.k2 ? this.i.k2.c : NaN;
        }
        set outlinedCornerRadiusTopLeft(v) {
            this.ensureOutlinedCornerRadius();
            this.i.k2.c = +v;
            this.i.k2 = this.i.k2;
        }
        get outlinedCornerRadiusTopRight() {
            return this.i.k2 ? this.i.k2.d : NaN;
        }
        set outlinedCornerRadiusTopRight(v) {
            this.ensureOutlinedCornerRadius();
            this.i.k2.d = +v;
            this.i.k2 = this.i.k2;
        }
        ensureOutlinedCornerRadius() {
            if (this.i.k2) {
                return;
            }
            this.i.k2 = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background when the button is pressed and the type is floating action button.
        */
        get outlinedRippleColor() {
            return brushToString(this.i.qt);
        }
        set outlinedRippleColor(v) {
            this.i.qt = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when type is outlined.
        */
        get outlinedTextColor() {
            return brushToString(this.i.qu);
        }
        set outlinedTextColor(v) {
            this.i.qu = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button when type is outlined.
        */
        get outlinedHoverTextColor() {
            return brushToString(this.i.qs);
        }
        set outlinedHoverTextColor(v) {
            this.i.qs = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused and outlined.
        */
        get outlinedFocusBackgroundColor() {
            return brushToString(this.i.qp);
        }
        set outlinedFocusBackgroundColor(v) {
            this.i.qp = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text the button when it is focused and outlined.
        */
        get outlinedFocusTextColor() {
            return brushToString(this.i.qq);
        }
        set outlinedFocusTextColor(v) {
            this.i.qq = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the background of the button when the  type is floating action button.
        */
        get fabBackgroundColor() {
            return brushToString(this.i.pj);
        }
        set fabBackgroundColor(v) {
            this.i.pj = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is fab.
        */
        get fabDisabledBackgroundColor() {
            return brushToString(this.i.pl);
        }
        set fabDisabledBackgroundColor(v) {
            this.i.pl = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is fab.
        */
        get fabDisabledBorderColor() {
            return brushToString(this.i.pm);
        }
        set fabDisabledBorderColor(v) {
            this.i.pm = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is fab.
        */
        get fabDisabledTextColor() {
            return brushToString(this.i.pn);
        }
        set fabDisabledTextColor(v) {
            this.i.pn = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is fab.
        */
        get fabDisabledElevation() {
            return this.i.df;
        }
        set fabDisabledElevation(v) {
            this.i.df = +v;
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the  type is hoveredFab.
        */
        get fabHoverBackgroundColor() {
            return brushToString(this.i.pq);
        }
        set fabHoverBackgroundColor(v) {
            this.i.pq = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button when the type is floating action button.
        */
        get fabBorderColor() {
            return brushToString(this.i.pk);
        }
        set fabBorderColor(v) {
            this.i.pk = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button when the type is floating action button.
        */
        get fabRestingElevation() {
            return this.i.di;
        }
        set fabRestingElevation(v) {
            this.i.di = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button when the type is floating action button.
        */
        get fabHoverElevation() {
            return this.i.dh;
        }
        set fabHoverElevation(v) {
            this.i.dh = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button when the type is floating action button.
        */
        get fabFocusElevation() {
            return this.i.dg;
        }
        set fabFocusElevation(v) {
            this.i.dg = +v;
        }
        /**
         * Gets or sets the width to use for the button border when the type is floating action button.
        */
        get fabBorderWidth() {
            return this.i.bq;
        }
        set fabBorderWidth(v) {
            this.i.bq = +v;
        }
        get fabCornerRadiusBottomRight() {
            return this.i.kz ? this.i.kz.b : NaN;
        }
        set fabCornerRadiusBottomRight(v) {
            this.ensureFabCornerRadius();
            this.i.kz.b = +v;
            this.i.kz = this.i.kz;
        }
        get fabCornerRadiusBottomLeft() {
            return this.i.kz ? this.i.kz.a : NaN;
        }
        set fabCornerRadiusBottomLeft(v) {
            this.ensureFabCornerRadius();
            this.i.kz.a = +v;
            this.i.kz = this.i.kz;
        }
        get fabCornerRadiusTopLeft() {
            return this.i.kz ? this.i.kz.c : NaN;
        }
        set fabCornerRadiusTopLeft(v) {
            this.ensureFabCornerRadius();
            this.i.kz.c = +v;
            this.i.kz = this.i.kz;
        }
        get fabCornerRadiusTopRight() {
            return this.i.kz ? this.i.kz.d : NaN;
        }
        set fabCornerRadiusTopRight(v) {
            this.ensureFabCornerRadius();
            this.i.kz.d = +v;
            this.i.kz = this.i.kz;
        }
        ensureFabCornerRadius() {
            if (this.i.kz) {
                return;
            }
            this.i.kz = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background when the button is pressed and the type is floating action button.
        */
        get fabRippleColor() {
            return brushToString(this.i.ps);
        }
        set fabRippleColor(v) {
            this.i.ps = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when type is floating action button.
        */
        get fabTextColor() {
            return brushToString(this.i.pt);
        }
        set fabTextColor(v) {
            this.i.pt = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button when type is floating action button.
        */
        get fabHoverTextColor() {
            return brushToString(this.i.pr);
        }
        set fabHoverTextColor(v) {
            this.i.pr = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused and fab.
        */
        get fabFocusBackgroundColor() {
            return brushToString(this.i.po);
        }
        set fabFocusBackgroundColor(v) {
            this.i.po = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text the button when it is focused and fab.
        */
        get fabFocusTextColor() {
            return brushToString(this.i.pp);
        }
        set fabFocusTextColor(v) {
            this.i.pp = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the background of the button when the  type is icon.
        */
        get iconBackgroundColor() {
            return brushToString(this.i.p9);
        }
        set iconBackgroundColor(v) {
            this.i.p9 = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled background of the button when the type is icon.
        */
        get iconDisabledBackgroundColor() {
            return brushToString(this.i.qb);
        }
        set iconDisabledBackgroundColor(v) {
            this.i.qb = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled border of the button when the type is icon.
        */
        get iconDisabledBorderColor() {
            return brushToString(this.i.qc);
        }
        set iconDisabledBorderColor(v) {
            this.i.qc = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the disabled text of the button when the type is icon.
        */
        get iconDisabledTextColor() {
            return brushToString(this.i.qd);
        }
        set iconDisabledTextColor(v) {
            this.i.qd = stringToBrush(v);
        }
        /**
         * Gets or sets the disabled elevation to use for the button when the type is icon.
        */
        get iconDisabledElevation() {
            return this.i.dq;
        }
        set iconDisabledElevation(v) {
            this.i.dq = +v;
        }
        /**
         * Gets or sets the hover color to use for the background of the button when the  type is hoveredIcon.
        */
        get iconHoverBackgroundColor() {
            return brushToString(this.i.qg);
        }
        set iconHoverBackgroundColor(v) {
            this.i.qg = stringToBrush(v);
        }
        /**
         * Gets or sets the border color to use for the button when the type is icon.
        */
        get iconBorderColor() {
            return brushToString(this.i.qa);
        }
        set iconBorderColor(v) {
            this.i.qa = stringToBrush(v);
        }
        /**
         * Gets or sets the elevation to use for the button when the type is icon.
        */
        get iconRestingElevation() {
            return this.i.dt;
        }
        set iconRestingElevation(v) {
            this.i.dt = +v;
        }
        /**
         * Gets or sets the hover elevation to use for the button when the type is icon.
        */
        get iconHoverElevation() {
            return this.i.ds;
        }
        set iconHoverElevation(v) {
            this.i.ds = +v;
        }
        /**
         * Gets or sets the focus elevation to use for the button when the type is icon.
        */
        get iconFocusElevation() {
            return this.i.dr;
        }
        set iconFocusElevation(v) {
            this.i.dr = +v;
        }
        /**
         * Gets or sets the width to use for the button border when the type is icon.
        */
        get iconBorderWidth() {
            return this.i.bs;
        }
        set iconBorderWidth(v) {
            this.i.bs = +v;
        }
        get iconCornerRadiusBottomRight() {
            return this.i.k1 ? this.i.k1.b : NaN;
        }
        set iconCornerRadiusBottomRight(v) {
            this.ensureIconCornerRadius();
            this.i.k1.b = +v;
            this.i.k1 = this.i.k1;
        }
        get iconCornerRadiusBottomLeft() {
            return this.i.k1 ? this.i.k1.a : NaN;
        }
        set iconCornerRadiusBottomLeft(v) {
            this.ensureIconCornerRadius();
            this.i.k1.a = +v;
            this.i.k1 = this.i.k1;
        }
        get iconCornerRadiusTopLeft() {
            return this.i.k1 ? this.i.k1.c : NaN;
        }
        set iconCornerRadiusTopLeft(v) {
            this.ensureIconCornerRadius();
            this.i.k1.c = +v;
            this.i.k1 = this.i.k1;
        }
        get iconCornerRadiusTopRight() {
            return this.i.k1 ? this.i.k1.d : NaN;
        }
        set iconCornerRadiusTopRight(v) {
            this.ensureIconCornerRadius();
            this.i.k1.d = +v;
            this.i.k1 = this.i.k1;
        }
        ensureIconCornerRadius() {
            if (this.i.k1) {
                return;
            }
            this.i.k1 = new CornerRadius(2);
        }
        /**
         * Gets or sets the color to use for the background when the button is pressed and the type is floating action button.
        */
        get iconRippleColor() {
            return brushToString(this.i.qi);
        }
        set iconRippleColor(v) {
            this.i.qi = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text of the button when type is icon.
        */
        get iconTextColor() {
            return brushToString(this.i.qj);
        }
        set iconTextColor(v) {
            this.i.qj = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the hovered text of the button when type is icon.
        */
        get iconHoverTextColor() {
            return brushToString(this.i.qh);
        }
        set iconHoverTextColor(v) {
            this.i.qh = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the backround the button when it is focused and icon.
        */
        get iconFocusBackgroundColor() {
            return brushToString(this.i.qe);
        }
        set iconFocusBackgroundColor(v) {
            this.i.qe = stringToBrush(v);
        }
        /**
         * Gets or sets the color to use for the text the button when it is focused and icon.
        */
        get iconFocusTextColor() {
            return brushToString(this.i.qf);
        }
        set iconFocusTextColor(v) {
            this.i.qf = stringToBrush(v);
        }
        /**
         * Gets or sets the id to use for the internal native checkbox.
        */
        get inputId() {
            return this.i.hu;
        }
        set inputId(v) {
            this.i.hu = v;
        }
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get id() {
            return this.i.hs;
        }
        set id(v) {
            this.i.hs = v;
        }
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get display() {
            return this.i.fw;
        }
        set display(v) {
            this.i.fw = v;
        }
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get flexDirection() {
            return this.i.g0;
        }
        set flexDirection(v) {
            this.i.g0 = v;
        }
        /**
         * Gets or sets the flex-grow setting for the button.
        */
        get flexGrow() {
            return this.i.g2;
        }
        set flexGrow(v) {
            this.i.g2 = v;
        }
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get alignItems() {
            return this.i.e7;
        }
        set alignItems(v) {
            this.i.e7 = v;
        }
        /**
         * Gets or sets value to use for the checkbox.
        */
        get value() {
            return this.i.ea;
        }
        set value(v) {
            this.i.ea = v;
        }
        /**
         * Gets or sets name to use for the button.
        */
        get name() {
            return this.i.h2;
        }
        set name(v) {
            this.i.h2 = v;
        }
        /**
         * Gets or sets TabIndex to use for the checkbox.
        */
        get tabIndex() {
            return this.i.d3;
        }
        set tabIndex(v) {
            this.i.d3 = +v;
        }
        /**
         * Gets or sets the value of the aria-label attribute.
        */
        get ariaLabel() {
            return this.i.e9;
        }
        set ariaLabel(v) {
            this.i.e9 = v;
        }
        /**
         * Gets or sets whether the button should fill the available space. If false, the button
         * will use an intrinsic size.
        */
        get fillAvailableSpace() {
            return this.i.av;
        }
        set fillAvailableSpace(v) {
            this.i.av = ensureBool(v);
        }
        /**
         * Gets or sets if the checkbox is Focused.
        */
        get focused() {
            return this.i.focused;
        }
        set focused(v) {
            this.i.focused = ensureBool(v);
        }
        /**
         * Gets or sets if the button show use styling to show focus.
        */
        get isFocusStyleEnabled() {
            return this.i.az;
        }
        set isFocusStyleEnabled(v) {
            this.i.az = ensureBool(v);
        }
        /**
         * Gets or sets whether to disable the ripple effect for the button.
        */
        get disableRipple() {
            return this.i.at;
        }
        set disableRipple(v) {
            this.i.at = ensureBool(v);
        }
        /**
         * Gets whether to actually disable the ripple effect for the button.
        */
        get actualDisableRipple() {
            return this.i.ap;
        }
        set actualDisableRipple(v) {
            this.i.ap = ensureBool(v);
        }
        /**
         * Gets or sets whether the hover effect is disabled.
        */
        get disableHover() {
            return this.i.ar;
        }
        set disableHover(v) {
            this.i.ar = ensureBool(v);
        }
        /**
         * Gets or sets whether the checkbox is checked.
        */
        get isHover() {
            return this.i.a0;
        }
        set isHover(v) {
            this.i.a0 = ensureBool(v);
        }
        /**
         * Gets or sets whether the checkbox is disabled.
        */
        get disabled() {
            return this.i.disabled;
        }
        set disabled(v) {
            this.i.disabled = ensureBool(v);
        }
        /**
         * Gets or sets whether the checkbox transitions are disabled.
        */
        get disableTransitions() {
            return this.i.au;
        }
        set disableTransitions(v) {
            this.i.au = ensureBool(v);
        }
        /**
         * Gets or sets whether the cursor will change into a pointer when the button is hovered.
        */
        get disablePointer() {
            return this.i.as;
        }
        set disablePointer(v) {
            this.i.as = ensureBool(v);
        }
        /**
         * Gets or sets the left padding for the button content.
        */
        get contentPaddingLeft() {
            return this.i.bi;
        }
        set contentPaddingLeft(v) {
            this.i.bi = +v;
        }
        /**
         * Gets or sets the top padding for the button content.
        */
        get contentPaddingTop() {
            return this.i.bk;
        }
        set contentPaddingTop(v) {
            this.i.bk = +v;
        }
        /**
         * Gets or sets the right padding for the button content.
        */
        get contentPaddingRight() {
            return this.i.bj;
        }
        set contentPaddingRight(v) {
            this.i.bj = +v;
        }
        /**
         * Gets or sets the bottom padding for the button content.
        */
        get contentPaddingBottom() {
            return this.i.bh;
        }
        set contentPaddingBottom(v) {
            this.i.bh = +v;
        }
        get horizontalContentAlignment() {
            return this.i.k5;
        }
        set horizontalContentAlignment(v) {
            this.i.k5 = ensureEnum(HorizontalAlignment_$type, v);
        }
        get verticalContentAlignment() {
            return this.i.q9;
        }
        set verticalContentAlignment(v) {
            this.i.q9 = ensureEnum(VerticalAlignment_$type, v);
        }
        /**
         * Gets or sets if clicking on the button is allowed to tunnel down to button content.
        */
        get clickTunneling() {
            return this.i.aq;
        }
        set clickTunneling(v) {
            this.i.aq = ensureBool(v);
        }
        findByName(name) {
            if (this.findEphemera) {
                if (name && name.indexOf("@@e:") == 0) {
                    return this.findEphemera(name);
                }
            }
            return null;
        }
        get hasUserValues() {
            return this._hasUserValues;
        }
        __m(propertyName) {
            if (!this._inStyling) {
                this._hasUserValues.add(propertyName);
            }
        }
        _styling(container, component, parent) {
            if (this._inStyling) {
                return;
            }
            this._inStyling = true;
            this._stylingContainer = container;
            this._stylingParent = component;
            let genericPrefix = "";
            let typeName = this.i.$type.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            genericPrefix = toSpinal("XButtonComponent");
            let additionalPrefixes = [];
            let prefix = toSpinal(typeName);
            additionalPrefixes.push(prefix + "-");
            let b = this.i.$type.baseType;
            while (b && b.name != "Object" &&
                b.name != "Base" &&
                b.name != "Control" &&
                b.Name != "DependencyObject" &&
                b.Name != "FrameworkElement") {
                typeName = b.name;
                if (typeName.indexOf("Xam") === 0) {
                    typeName = typeName.substring(3);
                }
                let basePrefix = toSpinal(typeName);
                additionalPrefixes.push(basePrefix + "-");
                b = b.baseType;
            }
            if (parent) {
                let parentTypeName = parent.i.$type.name;
                if (parentTypeName.indexOf("Xam") === 0) {
                    parentTypeName = parentTypeName.substring(3);
                }
                let parentPrefix = toSpinal(parentTypeName);
                additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
                additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
            }
            initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
            if (this._otherStyling) {
                this._otherStyling(container, component, parent);
            }
            this._inStyling = false;
        }
        onDetachedFromUI() {
            this.i.onDetachedFromUI();
        }
        onAttachedToUI() {
            this.i.onAttachedToUI();
        }
        /**
         * Exports visual information about the current state of the grid.
        
        */
        exportVisualModel() {
            let iv = this.i.d7();
            return (iv);
        }
        /**
         * Returns a serialized copy of the exported visual model
        
        */
        exportSerializedVisualModel() {
            let iv = this.i.f0();
            return (iv);
        }
        get clicked() {
            if (this._clicked == null) {
                this._clicked = new EventEmitter();
                this.i.clicked = delegateCombine(this.i.clicked, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxButtonClickEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeClicked) {
                            this.beforeClicked(this, outerArgs);
                        }
                        this._clicked.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._clicked;
        }
        get gotFocus() {
            if (this._gotFocus == null) {
                this._gotFocus = new EventEmitter();
                this.i.gotFocus = delegateCombine(this.i.gotFocus, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxFocusEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeGotFocus) {
                            this.beforeGotFocus(this, outerArgs);
                        }
                        this._gotFocus.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._gotFocus;
        }
        get lostFocus() {
            if (this._lostFocus == null) {
                this._lostFocus = new EventEmitter();
                this.i.lostFocus = delegateCombine(this.i.lostFocus, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxFocusEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeLostFocus) {
                            this.beforeLostFocus(this, outerArgs);
                        }
                        this._lostFocus.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._lostFocus;
        }
        _runInZone(act) {
            if (this._zoneRunner != null) {
                this._zoneRunner(act);
            }
            else {
                act();
            }
        }
    }
    IgxXButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxXButtonComponent, deps: [{ token: i0.Renderer2 }, { token: i0.ViewContainerRef }, { token: i0.NgZone }, { token: i0.Injector }, { token: i0.ComponentFactoryResolver }], target: i0.ɵɵFactoryTarget.Component });
    IgxXButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxXButtonComponent, selector: "igx-x-button", inputs: { minWidth: "minWidth", minHeight: "minHeight", displayType: "displayType", density: "density", baseTheme: "baseTheme", actualDensity: "actualDensity", actualBorderColor: "actualBorderColor", actualUmbraShadowColor: "actualUmbraShadowColor", actualPenumbraShadowColor: "actualPenumbraShadowColor", actualAmbientShadowColor: "actualAmbientShadowColor", actualRestingElevation: "actualRestingElevation", actualFocusElevation: "actualFocusElevation", actualHoverElevation: "actualHoverElevation", actualRippleColor: "actualRippleColor", actualCornerRadiusBottomRight: "actualCornerRadiusBottomRight", actualCornerRadiusBottomLeft: "actualCornerRadiusBottomLeft", actualCornerRadiusTopLeft: "actualCornerRadiusTopLeft", actualCornerRadiusTopRight: "actualCornerRadiusTopRight", actualBackgroundColor: "actualBackgroundColor", actualDisabledBackgroundColor: "actualDisabledBackgroundColor", actualDisabledBorderColor: "actualDisabledBorderColor", actualDisabledTextColor: "actualDisabledTextColor", actualDisabledElevation: "actualDisabledElevation", actualElevationMode: "actualElevationMode", actualTextColor: "actualTextColor", actualHoverTextColor: "actualHoverTextColor", actualFocusBackgroundColor: "actualFocusBackgroundColor", actualFocusTextColor: "actualFocusTextColor", actualHoverBackgroundColor: "actualHoverBackgroundColor", actualBorderWidth: "actualBorderWidth", raisedBackgroundColor: "raisedBackgroundColor", raisedDisabledBackgroundColor: "raisedDisabledBackgroundColor", raisedDisabledBorderColor: "raisedDisabledBorderColor", raisedDisabledTextColor: "raisedDisabledTextColor", raisedDisabledElevation: "raisedDisabledElevation", raisedHoverBackgroundColor: "raisedHoverBackgroundColor", raisedBorderColor: "raisedBorderColor", raisedRestingElevation: "raisedRestingElevation", raisedHoverElevation: "raisedHoverElevation", raisedFocusElevation: "raisedFocusElevation", raisedBorderWidth: "raisedBorderWidth", raisedCornerRadiusBottomRight: "raisedCornerRadiusBottomRight", raisedCornerRadiusBottomLeft: "raisedCornerRadiusBottomLeft", raisedCornerRadiusTopLeft: "raisedCornerRadiusTopLeft", raisedCornerRadiusTopRight: "raisedCornerRadiusTopRight", raisedRippleColor: "raisedRippleColor", flatBackgroundColor: "flatBackgroundColor", flatDisabledBackgroundColor: "flatDisabledBackgroundColor", flatDisabledBorderColor: "flatDisabledBorderColor", flatDisabledTextColor: "flatDisabledTextColor", flatDisabledElevation: "flatDisabledElevation", flatHoverBackgroundColor: "flatHoverBackgroundColor", flatBorderColor: "flatBorderColor", flatRestingElevation: "flatRestingElevation", flatHoverElevation: "flatHoverElevation", flatFocusElevation: "flatFocusElevation", flatRippleColor: "flatRippleColor", flatTextColor: "flatTextColor", flatHoverTextColor: "flatHoverTextColor", flatFocusBackgroundColor: "flatFocusBackgroundColor", flatFocusTextColor: "flatFocusTextColor", flatBorderWidth: "flatBorderWidth", flatCornerRadiusBottomRight: "flatCornerRadiusBottomRight", flatCornerRadiusBottomLeft: "flatCornerRadiusBottomLeft", flatCornerRadiusTopLeft: "flatCornerRadiusTopLeft", flatCornerRadiusTopRight: "flatCornerRadiusTopRight", backgroundColor: "backgroundColor", disabledBackgroundColor: "disabledBackgroundColor", disabledBorderColor: "disabledBorderColor", disabledTextColor: "disabledTextColor", disabledElevation: "disabledElevation", elevationMode: "elevationMode", hoverBackgroundColor: "hoverBackgroundColor", borderColor: "borderColor", restingElevation: "restingElevation", hoverElevation: "hoverElevation", focusElevation: "focusElevation", textStyle: "textStyle", textColor: "textColor", hoverTextColor: "hoverTextColor", rippleColor: "rippleColor", raisedTextColor: "raisedTextColor", raisedHoverTextColor: "raisedHoverTextColor", raisedFocusBackgroundColor: "raisedFocusBackgroundColor", raisedFocusTextColor: "raisedFocusTextColor", focusBackgroundColor: "focusBackgroundColor", focusTextColor: "focusTextColor", borderWidth: "borderWidth", cornerRadiusBottomRight: "cornerRadiusBottomRight", cornerRadiusBottomLeft: "cornerRadiusBottomLeft", cornerRadiusTopLeft: "cornerRadiusTopLeft", cornerRadiusTopRight: "cornerRadiusTopRight", outlinedBackgroundColor: "outlinedBackgroundColor", outlinedDisabledBackgroundColor: "outlinedDisabledBackgroundColor", outlinedDisabledBorderColor: "outlinedDisabledBorderColor", outlinedDisabledTextColor: "outlinedDisabledTextColor", outlinedDisabledElevation: "outlinedDisabledElevation", outlinedHoverBackgroundColor: "outlinedHoverBackgroundColor", outlinedBorderColor: "outlinedBorderColor", outlinedRestingElevation: "outlinedRestingElevation", outlinedHoverElevation: "outlinedHoverElevation", outlinedFocusElevation: "outlinedFocusElevation", outlinedBorderWidth: "outlinedBorderWidth", outlinedCornerRadiusBottomRight: "outlinedCornerRadiusBottomRight", outlinedCornerRadiusBottomLeft: "outlinedCornerRadiusBottomLeft", outlinedCornerRadiusTopLeft: "outlinedCornerRadiusTopLeft", outlinedCornerRadiusTopRight: "outlinedCornerRadiusTopRight", outlinedRippleColor: "outlinedRippleColor", outlinedTextColor: "outlinedTextColor", outlinedHoverTextColor: "outlinedHoverTextColor", outlinedFocusBackgroundColor: "outlinedFocusBackgroundColor", outlinedFocusTextColor: "outlinedFocusTextColor", fabBackgroundColor: "fabBackgroundColor", fabDisabledBackgroundColor: "fabDisabledBackgroundColor", fabDisabledBorderColor: "fabDisabledBorderColor", fabDisabledTextColor: "fabDisabledTextColor", fabDisabledElevation: "fabDisabledElevation", fabHoverBackgroundColor: "fabHoverBackgroundColor", fabBorderColor: "fabBorderColor", fabRestingElevation: "fabRestingElevation", fabHoverElevation: "fabHoverElevation", fabFocusElevation: "fabFocusElevation", fabBorderWidth: "fabBorderWidth", fabCornerRadiusBottomRight: "fabCornerRadiusBottomRight", fabCornerRadiusBottomLeft: "fabCornerRadiusBottomLeft", fabCornerRadiusTopLeft: "fabCornerRadiusTopLeft", fabCornerRadiusTopRight: "fabCornerRadiusTopRight", fabRippleColor: "fabRippleColor", fabTextColor: "fabTextColor", fabHoverTextColor: "fabHoverTextColor", fabFocusBackgroundColor: "fabFocusBackgroundColor", fabFocusTextColor: "fabFocusTextColor", iconBackgroundColor: "iconBackgroundColor", iconDisabledBackgroundColor: "iconDisabledBackgroundColor", iconDisabledBorderColor: "iconDisabledBorderColor", iconDisabledTextColor: "iconDisabledTextColor", iconDisabledElevation: "iconDisabledElevation", iconHoverBackgroundColor: "iconHoverBackgroundColor", iconBorderColor: "iconBorderColor", iconRestingElevation: "iconRestingElevation", iconHoverElevation: "iconHoverElevation", iconFocusElevation: "iconFocusElevation", iconBorderWidth: "iconBorderWidth", iconCornerRadiusBottomRight: "iconCornerRadiusBottomRight", iconCornerRadiusBottomLeft: "iconCornerRadiusBottomLeft", iconCornerRadiusTopLeft: "iconCornerRadiusTopLeft", iconCornerRadiusTopRight: "iconCornerRadiusTopRight", iconRippleColor: "iconRippleColor", iconTextColor: "iconTextColor", iconHoverTextColor: "iconHoverTextColor", iconFocusBackgroundColor: "iconFocusBackgroundColor", iconFocusTextColor: "iconFocusTextColor", inputId: "inputId", id: "id", display: "display", flexDirection: "flexDirection", flexGrow: "flexGrow", alignItems: "alignItems", value: "value", name: "name", tabIndex: ["tabindex", "tabIndex"], ariaLabel: ["aria-label", "ariaLabel"], fillAvailableSpace: "fillAvailableSpace", focused: "focused", isFocusStyleEnabled: "isFocusStyleEnabled", disableRipple: "disableRipple", actualDisableRipple: "actualDisableRipple", disableHover: "disableHover", isHover: "isHover", disabled: "disabled", disableTransitions: "disableTransitions", disablePointer: "disablePointer", contentPaddingLeft: "contentPaddingLeft", contentPaddingTop: "contentPaddingTop", contentPaddingRight: "contentPaddingRight", contentPaddingBottom: "contentPaddingBottom", horizontalContentAlignment: "horizontalContentAlignment", verticalContentAlignment: "verticalContentAlignment", clickTunneling: "clickTunneling" }, outputs: { clicked: "clicked", gotFocus: "gotFocus", lostFocus: "lostFocus" }, host: { properties: { "attr.id": "this.id", "style.display": "this.display", "style.flexDirection": "this.flexDirection", "style.flexGrow": "this.flexGrow", "style.alignItems": "this.alignItems" }, classAttribute: "ig-x-button igx-x-button" }, providers: [], viewQueries: [{ propertyName: "_dynamicContent", first: true, predicate: ["dynamicContent"], descendants: true, read: ViewContainerRef, static: true }, { propertyName: "_childTemplateRef", first: true, predicate: ["childContent"], descendants: true, read: TemplateRef }], ngImport: i0, template: `<ng-template #childContent><ng-content></ng-content></ng-template>
<ng-container #dynamicContent></ng-container>`, isInline: true, styles: ["\n\t\t:host {\n\t\t\tdisplay: inline-block;           \n\t\t}\n\t"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxXButtonComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxXButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-x-button',
                    template: `<ng-template #childContent><ng-content></ng-content></ng-template>
<ng-container #dynamicContent></ng-container>`,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    providers: [],
                    host: { 'class': 'ig-x-button igx-x-button' },
                    styles: [`
		:host {
			display: inline-block;           
		}
	`]
                }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }, { type: i0.ViewContainerRef }, { type: i0.NgZone }, { type: i0.Injector }, { type: i0.ComponentFactoryResolver }]; }, propDecorators: { _dynamicContent: [{
                type: ViewChild,
                args: ["dynamicContent", { read: ViewContainerRef, static: true }]
            }], _childTemplateRef: [{
                type: ViewChild,
                args: ["childContent", { read: TemplateRef, static: false }]
            }], minWidth: [{
                type: Input
            }], minHeight: [{
                type: Input
            }], displayType: [{
                type: Input
            }], density: [{
                type: Input
            }], baseTheme: [{
                type: Input
            }], actualDensity: [{
                type: Input
            }], actualBorderColor: [{
                type: Input
            }], actualUmbraShadowColor: [{
                type: Input
            }], actualPenumbraShadowColor: [{
                type: Input
            }], actualAmbientShadowColor: [{
                type: Input
            }], actualRestingElevation: [{
                type: Input
            }], actualFocusElevation: [{
                type: Input
            }], actualHoverElevation: [{
                type: Input
            }], actualRippleColor: [{
                type: Input
            }], actualCornerRadiusBottomRight: [{
                type: Input
            }], actualCornerRadiusBottomLeft: [{
                type: Input
            }], actualCornerRadiusTopLeft: [{
                type: Input
            }], actualCornerRadiusTopRight: [{
                type: Input
            }], actualBackgroundColor: [{
                type: Input
            }], actualDisabledBackgroundColor: [{
                type: Input
            }], actualDisabledBorderColor: [{
                type: Input
            }], actualDisabledTextColor: [{
                type: Input
            }], actualDisabledElevation: [{
                type: Input
            }], actualElevationMode: [{
                type: Input
            }], actualTextColor: [{
                type: Input
            }], actualHoverTextColor: [{
                type: Input
            }], actualFocusBackgroundColor: [{
                type: Input
            }], actualFocusTextColor: [{
                type: Input
            }], actualHoverBackgroundColor: [{
                type: Input
            }], actualBorderWidth: [{
                type: Input
            }], raisedBackgroundColor: [{
                type: Input
            }], raisedDisabledBackgroundColor: [{
                type: Input
            }], raisedDisabledBorderColor: [{
                type: Input
            }], raisedDisabledTextColor: [{
                type: Input
            }], raisedDisabledElevation: [{
                type: Input
            }], raisedHoverBackgroundColor: [{
                type: Input
            }], raisedBorderColor: [{
                type: Input
            }], raisedRestingElevation: [{
                type: Input
            }], raisedHoverElevation: [{
                type: Input
            }], raisedFocusElevation: [{
                type: Input
            }], raisedBorderWidth: [{
                type: Input
            }], raisedCornerRadiusBottomRight: [{
                type: Input
            }], raisedCornerRadiusBottomLeft: [{
                type: Input
            }], raisedCornerRadiusTopLeft: [{
                type: Input
            }], raisedCornerRadiusTopRight: [{
                type: Input
            }], raisedRippleColor: [{
                type: Input
            }], flatBackgroundColor: [{
                type: Input
            }], flatDisabledBackgroundColor: [{
                type: Input
            }], flatDisabledBorderColor: [{
                type: Input
            }], flatDisabledTextColor: [{
                type: Input
            }], flatDisabledElevation: [{
                type: Input
            }], flatHoverBackgroundColor: [{
                type: Input
            }], flatBorderColor: [{
                type: Input
            }], flatRestingElevation: [{
                type: Input
            }], flatHoverElevation: [{
                type: Input
            }], flatFocusElevation: [{
                type: Input
            }], flatRippleColor: [{
                type: Input
            }], flatTextColor: [{
                type: Input
            }], flatHoverTextColor: [{
                type: Input
            }], flatFocusBackgroundColor: [{
                type: Input
            }], flatFocusTextColor: [{
                type: Input
            }], flatBorderWidth: [{
                type: Input
            }], flatCornerRadiusBottomRight: [{
                type: Input
            }], flatCornerRadiusBottomLeft: [{
                type: Input
            }], flatCornerRadiusTopLeft: [{
                type: Input
            }], flatCornerRadiusTopRight: [{
                type: Input
            }], backgroundColor: [{
                type: Input
            }], disabledBackgroundColor: [{
                type: Input
            }], disabledBorderColor: [{
                type: Input
            }], disabledTextColor: [{
                type: Input
            }], disabledElevation: [{
                type: Input
            }], elevationMode: [{
                type: Input
            }], hoverBackgroundColor: [{
                type: Input
            }], borderColor: [{
                type: Input
            }], restingElevation: [{
                type: Input
            }], hoverElevation: [{
                type: Input
            }], focusElevation: [{
                type: Input
            }], textStyle: [{
                type: Input
            }], textColor: [{
                type: Input
            }], hoverTextColor: [{
                type: Input
            }], rippleColor: [{
                type: Input
            }], raisedTextColor: [{
                type: Input
            }], raisedHoverTextColor: [{
                type: Input
            }], raisedFocusBackgroundColor: [{
                type: Input
            }], raisedFocusTextColor: [{
                type: Input
            }], focusBackgroundColor: [{
                type: Input
            }], focusTextColor: [{
                type: Input
            }], borderWidth: [{
                type: Input
            }], cornerRadiusBottomRight: [{
                type: Input
            }], cornerRadiusBottomLeft: [{
                type: Input
            }], cornerRadiusTopLeft: [{
                type: Input
            }], cornerRadiusTopRight: [{
                type: Input
            }], outlinedBackgroundColor: [{
                type: Input
            }], outlinedDisabledBackgroundColor: [{
                type: Input
            }], outlinedDisabledBorderColor: [{
                type: Input
            }], outlinedDisabledTextColor: [{
                type: Input
            }], outlinedDisabledElevation: [{
                type: Input
            }], outlinedHoverBackgroundColor: [{
                type: Input
            }], outlinedBorderColor: [{
                type: Input
            }], outlinedRestingElevation: [{
                type: Input
            }], outlinedHoverElevation: [{
                type: Input
            }], outlinedFocusElevation: [{
                type: Input
            }], outlinedBorderWidth: [{
                type: Input
            }], outlinedCornerRadiusBottomRight: [{
                type: Input
            }], outlinedCornerRadiusBottomLeft: [{
                type: Input
            }], outlinedCornerRadiusTopLeft: [{
                type: Input
            }], outlinedCornerRadiusTopRight: [{
                type: Input
            }], outlinedRippleColor: [{
                type: Input
            }], outlinedTextColor: [{
                type: Input
            }], outlinedHoverTextColor: [{
                type: Input
            }], outlinedFocusBackgroundColor: [{
                type: Input
            }], outlinedFocusTextColor: [{
                type: Input
            }], fabBackgroundColor: [{
                type: Input
            }], fabDisabledBackgroundColor: [{
                type: Input
            }], fabDisabledBorderColor: [{
                type: Input
            }], fabDisabledTextColor: [{
                type: Input
            }], fabDisabledElevation: [{
                type: Input
            }], fabHoverBackgroundColor: [{
                type: Input
            }], fabBorderColor: [{
                type: Input
            }], fabRestingElevation: [{
                type: Input
            }], fabHoverElevation: [{
                type: Input
            }], fabFocusElevation: [{
                type: Input
            }], fabBorderWidth: [{
                type: Input
            }], fabCornerRadiusBottomRight: [{
                type: Input
            }], fabCornerRadiusBottomLeft: [{
                type: Input
            }], fabCornerRadiusTopLeft: [{
                type: Input
            }], fabCornerRadiusTopRight: [{
                type: Input
            }], fabRippleColor: [{
                type: Input
            }], fabTextColor: [{
                type: Input
            }], fabHoverTextColor: [{
                type: Input
            }], fabFocusBackgroundColor: [{
                type: Input
            }], fabFocusTextColor: [{
                type: Input
            }], iconBackgroundColor: [{
                type: Input
            }], iconDisabledBackgroundColor: [{
                type: Input
            }], iconDisabledBorderColor: [{
                type: Input
            }], iconDisabledTextColor: [{
                type: Input
            }], iconDisabledElevation: [{
                type: Input
            }], iconHoverBackgroundColor: [{
                type: Input
            }], iconBorderColor: [{
                type: Input
            }], iconRestingElevation: [{
                type: Input
            }], iconHoverElevation: [{
                type: Input
            }], iconFocusElevation: [{
                type: Input
            }], iconBorderWidth: [{
                type: Input
            }], iconCornerRadiusBottomRight: [{
                type: Input
            }], iconCornerRadiusBottomLeft: [{
                type: Input
            }], iconCornerRadiusTopLeft: [{
                type: Input
            }], iconCornerRadiusTopRight: [{
                type: Input
            }], iconRippleColor: [{
                type: Input
            }], iconTextColor: [{
                type: Input
            }], iconHoverTextColor: [{
                type: Input
            }], iconFocusBackgroundColor: [{
                type: Input
            }], iconFocusTextColor: [{
                type: Input
            }], inputId: [{
                type: Input
            }], id: [{
                type: HostBinding,
                args: ['attr.id']
            }, {
                type: Input
            }], display: [{
                type: HostBinding,
                args: ['style.display']
            }, {
                type: Input
            }], flexDirection: [{
                type: HostBinding,
                args: ['style.flexDirection']
            }, {
                type: Input
            }], flexGrow: [{
                type: HostBinding,
                args: ['style.flexGrow']
            }, {
                type: Input
            }], alignItems: [{
                type: HostBinding,
                args: ['style.alignItems']
            }, {
                type: Input
            }], value: [{
                type: Input
            }], name: [{
                type: Input
            }], tabIndex: [{
                type: Input,
                args: ['tabindex']
            }], ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }], fillAvailableSpace: [{
                type: Input
            }], focused: [{
                type: Input
            }], isFocusStyleEnabled: [{
                type: Input
            }], disableRipple: [{
                type: Input
            }], actualDisableRipple: [{
                type: Input
            }], disableHover: [{
                type: Input
            }], isHover: [{
                type: Input
            }], disabled: [{
                type: Input
            }], disableTransitions: [{
                type: Input
            }], disablePointer: [{
                type: Input
            }], contentPaddingLeft: [{
                type: Input
            }], contentPaddingTop: [{
                type: Input
            }], contentPaddingRight: [{
                type: Input
            }], contentPaddingBottom: [{
                type: Input
            }], horizontalContentAlignment: [{
                type: Input
            }], verticalContentAlignment: [{
                type: Input
            }], clickTunneling: [{
                type: Input
            }], clicked: [{
                type: Output
            }], gotFocus: [{
                type: Output
            }], lostFocus: [{
                type: Output
            }] } });
